{% load url from future %}
<div id="djohno_nav">
  <ul>
    <li>
      <a href="{% url 'djohno_frame' %}" title="Djohno home">Home</a>
    </li>
    <li>
      <a href="{% url 'djohno_frame_403' %}" title="Djohno 403">403</a>
    </li>
    <li>
      <a href="{% url 'djohno_frame_404' %}" title="Djohno 404">404</a>
    </li>
    <li>
      <a href="{% url 'djohno_frame_500' %}" title="Djohno 500">500</a>
    </li>
    <li>
      <a href="{% url 'djohno_frame_email' %}" title="Test email integration">Mail</a>
    </li>
    <li>
      <a href="{% url 'djohno_frame_versions' %}" title="View app versions">Versions</a>
    </li>
  </ul>
</div>
