html, body {
    margin: 0;
    height: 100%;
}

iframe {
    height: 100%;
    display: block;
    position: fixed;
}

#djohno_nav {
    width: 100%;
    background-color: #111;
    height: 62px;
    opacity: 0.8;
}

#djohno_nav ul {
    list-style: none;
    margin: 0;
    padding: 10px 0 0 50px;
}

#djohno_nav ul li {
    float: left;
    margin: 10px 15px 10px 0;
}

#djohno_nav ul li a {
  background-color: #1abc9c;
  border: none;
  color: #ffffff;
  text-decoration: none;
  text-shadow: none;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
  -webkit-box-shadow: none;
  -moz-box-shadow: none;
  box-shadow: none;
  font-family: "Georgia", sans-serif;
  font-size: 16.996px;
  font-weight: 500;
  line-height: 20px;
  padding: 8px 18px 9px;
  -webkit-transition: 0.25s;
  -moz-transition: 0.25s;
  -o-transition: 0.25s;
  transition: 0.25s;
  -webkit-backface-visibility: hidden;
}

#djohno_nav ul li a:hover {
  background-color: #48c9b0;
  color: #ffffff;
  outline: none;
  -webkit-transition: 0.25s;
  -moz-transition: 0.25s;
  -o-transition: 0.25s;
  transition: 0.25s;
  -webkit-backface-visibility: hidden;
}
