<code>DEFAULT_FROM_EMAIL</code> isn&rsquo;t specified in
your <code>settings.py</code> - you should set it to a valid email
address - preferably something like
<code>Your Name &lt;you@example.com&gt;</code>.
