html, body {
    margin: 0;
    padding: 0;
    height: 100%;
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}

body * {
    padding: 0;
    margin: 0;
}

.content {
    padding: 20px 50px;
}

.content h1 {
  font-size: 36px;
  line-height: 40px;
  margin-bottom: 0.5em;
}

.content p {
  margin-bottom: 20px;
  font-size: 21px;
  font-weight: 200;
  line-height: 30px;
}

code,
pre
 {
    font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
    padding: 2px 4px;
    color: #d14;
    white-space: nowrap;
    background-color: #f7f7f9;
    border: 1px solid #e1e1e8;
}

.table {
  margin-bottom: 20px;
}

.table th,
.table td {
  padding: 8px;
  line-height: 20px;
  text-align: left;
  border-top: 1px solid #dddddd;
  min-width: 200px;
}

.table th {
  font-weight: bold;
}

.table thead:first-child tr:first-child th,
.table thead:first-child tr:first-child td {
  border-top: 0;
}

.table tbody + tbody {
  border-top: 2px solid #dddddd;
}

.table-striped tbody tr:nth-child(odd) td,
.table-striped tbody tr:nth-child(odd) th {
  background-color: #f9f9f9;
}

.table-hover tbody tr:hover td,
.table-hover tbody tr:hover th {
  background-color: #f5f5f5;
}
