{% extends "djohno/base.html" %}

{% block content %}
<p><strong>Python</strong> {{ sys }}</p>

<table class="table table-striped table-hover">
  <thead>
    <tr>
      <th>App</th>
      <th>Version</th>
    </tr>
  </thead>
  <tbody>
{% for app, version in versions.items %}
  <tr>
    <td>{{ app }}</td><td>{{ version }}</td>
  </tr>
{% endfor %}
  </tbody>
</table>

{% endblock %}
