<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
    <title>Djohno Error Check</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="description" content="" />
    <meta name="author" content="" />
    <link rel="stylesheet" type="text/css" media="all" href="{{ STATIC_URL }}djohno/djohno_pages.css" />
  </head>
  <body>
    <div class="content">
      <h1>Djohno</h1>
      <p id="djohno_welcome">
        {% block content %}
        {% endblock %}
      </p>
    </div>
  </body>
</html>

