{% extends "djohno/base.html" %}

{% block content %}
  <strong>Hey!</strong>

  This is a quick tool for testing your site is set up to respond
  to various error statuses correctly. To get started, use the
  links above.
{% endblock %}
