<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
    <title>{{ title }}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="description" content="" />
    <meta name="author" content="" />
    <link rel="stylesheet" type="text/css" media="all" href="{{ STATIC_URL }}djohno/style.css" />
  </head>
  <body>
    {% include "djohno/_djohno_dose.html" %}
    <iframe src="{{ frame_url }}" width="100%" frameborder="0" name="djohno_frame" />
  </body>
</html>

